@@ -10,7 +10,7 @@ try:
     # Change here if project is renamed and does not equal the package name
     dist_name = "pyscaffoldext-markdown"
     __version__ = version(dist_name)
-except PackageNotFoundError:
-    __version__ = "unknown"  # pragma: no cover
+except PackageNotFoundError:  # pragma: no cover
+    __version__ = "unknown"
 finally:
     del version, PackageNotFoundError
